Methodology
===========

Integration
-----------

In the case of the tool integration with existing co-simulation design
flows, it could be desired to have a set of migration functions that
enable easy use of the integration from a design flow based on
``OpenLane v1`` whilst enabling porting into ``OpenLane v2``.

A wrapper function to enable this is the ``openlane_migration`` [//]: #
(TODO include openlane_migration links)

.. toctree::

    relevant_electronic_projects
